/**
 * 
 */
package net.bigeon.gclc.process;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.fail;

import java.io.IOException;

import org.junit.Test;

import net.bigeon.gclc.exception.CommandRunException;
import net.bigeon.gclc.exception.CommandRunExceptionType;
import net.bigeon.gclc.process.mocks.TaskMock;

/** @author Emmanuel Bigeon */
public class ProcessKillTest {

    /** Test method for
     * {@link net.bigeon.gclc.process.ProcessKill#ProcessKill(java.lang.String, net.bigeon.gclc.process.TaskPool)}. */
    @Test
    public void testProcessKill() {
        final ProcessList pl = new ProcessList("kill", new TaskPool());
        assertEquals("Command name should be kept as specified", "kill",
                pl.getCommandName());
    }

    /** Test method for
     * {@link net.bigeon.gclc.process.ProcessKill#execute(net.bigeon.gclc.manager.ConsoleOutput, net.bigeon.gclc.manager.ConsoleInput, java.lang.String[])}.
     * 
     * @throws CommandRunException if an error occured in test
     * @throws IOException if an error occured with the console output */
    @Test
    public void testExecute() throws CommandRunException {
        final TaskPool pool = new TaskPool();
        final TaskMock task = new TaskMock();
        final int id = pool.add(task);
        final ProcessKill pl = new ProcessKill("kill", pool);
        task.reset();
        try {
            pl.execute(null, null);
            fail("Execution with no pid should raise exception");
        } catch (final CommandRunException e) {
            assertEquals("Usage exception expected", CommandRunExceptionType.USAGE,
                    e.getType());
        }
        pl.execute(null, null, Integer.toString(id));
        assertEquals("Task should be shutdown", 1, task.getNumberSetRunning());
        task.reset();
        pl.execute(null, null, Integer.toString(id));
        assertEquals("Task should be shutdown", 1, task.getNumberSetRunning());
    }

    /** Test method for {@link net.bigeon.gclc.process.ProcessKill#tip()}. */
    @Test
    public void testTip() {
        final ProcessKill pl = new ProcessKill("kill", new TaskPool());
        assertNotNull("Command tip should be defined", pl.tip());
        assertNotNull("Command usage should be defined", pl.usagePattern());
        assertNotNull("Command usage should be defined", pl.usageDetail());
    }

}
